function [Time,URLSITE,URLPATH,URLFILE]=cat_pathfinder4km(R)

%function [Time,URLSITE,URLPATH,URLFILE]=cat_pathfinder4km_clim(R)
if isfield(R,'DataSetBranch') & strcmp(R.DataSetBranch,'Pathfinder4km_Climatology')
% catalog of files for Pathfinder4km Climatology
% input R.TAVG,R.Passes, optional R.DATE1,R.DATE2,R.DATEINCR

URLSITE='http://satdat1.gso.uri.edu/opendap/sea_surface_temperature/climatology/pathfinder/Version5.0/';

if ~isfield(R,'TAvg') R.TAvg='daily'; end
if ~isfield(R,'Passes') R.Passes={'night','day'}; end

% MATLAB 7.5 has a bug in datenum at year 0001-04-01
% use year 2000 as base instead to deal with climatology
% Note MATLAB datenum uses Julian calendar before October 4, 1582
% and Gregorian calendar after October 15, 1582
% 2000 (and 1600) is a leap year in both Julian and Gregorian calendars
% We need a leap year as a base year in order to access yearday 366
if ~isfield(R,'BaseYear') 
    R.BaseYear=0000; 
elseif ischar(R.BaseYear) 
    R.BaseYear=str2num(R.BaseYear);
end
YYYY=num2str(R.BaseYear,'%04d');
if ~isfield(R,'DATE1') R.DATE1='00000101'; end
if ~isfield(R,'DATE2') R.DATE2='00001231'; end
if ~isfield(R,'DATEINCR') R.DATEINCR=1; end
JD1=datenum([YYYY R.DATE1(5:end)],'yyyymmdd');
JD2=datenum([YYYY R.DATE2(5:end)],'yyyymmdd');
% to allow intervals spanning a New Year, e.g. Dec-Jan
if JD2<JD1 JD2=datenum([num2str(R.BaseYear+1,'%04d') R.DATE2(5:end)],'yyyymmdd'); end
   
PASSPATH='Combined/';PASSFN='combined';hhd=8/24; 
    if isempty(strmatch(R.Passes,'day')) 
%R.Clim_Passes='night';
PASSPATH='Night/';PASSFN='night';hhd=2/24;
    end
    if isempty(strmatch(R.Passes,'night')) 
%R.Clim_Passes='day';
PASSPATH='Day/';PASSFN='day';hhd=14/24;
    end

%error: R2007b
% datenum('00000101','yyyymmdd')=1
% datenum(0,1,1)=0
    
    if ~isempty(strmatch(R.TAvg,{'daily','day','1day'}))
URLPATH=['/Daily/' PASSPATH];ND=1;NT=366;TAVGFN='day';TAVGFNFMT='%03d';
k=JD1;j=k-datenum(str2num(datestr(k,'yyyy')),1,1)+1;JT1=floor((j-1)/ND)+1;
k=JD2;j=k-datenum(str2num(datestr(k,'yyyy')),1,1)+1;JT2=floor((j-1)/ND)+1; 
    elseif ~isempty(strmatch(R.TAvg,{'5day','pentad'}))
URLPATH=['/5day/' PASSPATH];ND=5;NT=73;TAVGFN='pentad';TAVGFNFMT='%02d';
k=JD1;j=k-datenum(str2num(datestr(k,'yyyy')),1,1)+1;JT1=floor((j-1)/ND)+1;
k=JD2;j=k-datenum(str2num(datestr(k,'yyyy')),1,1)+1;JT2=floor((j-1)/ND)+1; 
    elseif ~isempty(strmatch(R.TAvg,{'7day','week','weekly'}))
URLPATH=['/7day/' PASSPATH];ND=7;NT=52;TAVGFN='week';TAVGFNFMT='%02d';
k=JD1;j=k-datenum(str2num(datestr(k,'yyyy')),1,1)+1;JT1=floor((j-1)/ND)+1;
k=JD2;j=k-datenum(str2num(datestr(k,'yyyy')),1,1)+1;JT2=floor((j-1)/ND)+1; 
    elseif ~isempty(strmatch(R.TAvg,{'8day','octad'}))
URLPATH=['/8day/' PASSPATH];ND=8;NT=45;TAVGFN='octad';TAVGFNFMT='%02d';
k=JD1;j=k-datenum(str2num(datestr(k,'yyyy')),1,1)+1;JT1=floor((j-1)/ND)+1;
k=JD2;j=k-datenum(str2num(datestr(k,'yyyy')),1,1)+1;JT2=floor((j-1)/ND)+1; 
    elseif ~isempty(strmatch(R.TAvg,{'monthly','month','30day'}))
URLPATH=['/Monthly/' PASSPATH];ND=30;NT=12;TAVGFN='month';TAVGFNFMT='%02d';
k=JD1;JT1=str2num(datestr(k,'mm'));
k=JD2;JT2=str2num(datestr(k,'mm'));
    elseif ~isempty(strmatch(R.TAvg,{'seasonal','season','90day'}))
URLPATH=['/Seasonal/' PASSPATH];ND=90;NT=4;TAVGFN='season';TAVGFNFMT='%01d';
k=JD1;j=str2num(datestr(k,'mm'));JT1=floor((j-1)/3)+1;
k=JD2;j=str2num(datestr(k,'mm'));JT2=floor((j-1)/3)+1;
    elseif ~isempty(strmatch(R.TAvg,{'annual','yearly','year','365day','12month'}))
URLPATH=['/Annual/' PASSPATH];ND=366;NT=1;TAVGFN='annual';TAVGFNFMT='%00d';
JT1=1;
JT2=1;
    end

if JT2<JT1 JT2=JT2+NT; end
kF=0;
for k=JT1:R.DATEINCR:JT2
kT=mod(k-1,NT)+1;
kF=kF+1;
URLFILE{kF}=[TAVGFN num2str(kT,TAVGFNFMT) '_' PASSFN '.hdf'];
end
URLFILE=URLFILE';

k=(JT1:R.DATEINCR:JT2)';
[tA tB tC]=op_tavgind2datenum(k,R);
Time=tA+hhd;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
else

% catalog of files for Pathfinder4km
% based on the file naming conventions described in PFV50_UserGuide.pdf
% input R.TAVG,R.Passes, optional R.DATE1,R.DATE2,R.DATEINCR
%
% NODC
% opendap access:
% http://data.nodc.noaa.gov/cgi-bin/nph-dods/pathfinder
% climatology
% http://data.nodc.noaa.gov/cgi-bin/nph-dods/pathfinder/Version5.0_Climatologies

% JPL NASA
% http://dods.jpl.nasa.gov/opendap/sea_surface_temperature/avhrr/pathfinder/
%data_v5/5day/night/04km/1991/sst/contents.html
% Example of an individual data file URL:
%'http://dods.jpl.nasa.gov/opendap/sea_surface_temperature/avhrr/pathfinder
%/data_v5/daily/ascending/04km/2005/sst/2005001.s04d4pfv50-sst.hdf
%?sst[0:1:4095][0:1:8191]'

URLSITE='http://dods.jpl.nasa.gov/opendap/sea_surface_temperature/avhrr/pathfinder/data_v5';
TAvg={'yearly';'monthly';'8day';'7day';'5day';'daily'}; % directory name in the latest dataset
%URLPass={'ascending';'descending'};
DSPass={'night';'day'};
DSPassLST={2/24;14/24}; % approx local solar time of a pass 
Fields={'sst';'bsst';'sdev';'nobs';'qual';'msk1';'msk2'};

if ~isfield(R,'TAvg') R.TAvg='daily'; end
TAVG=R.TAvg;

% dataset available time range
DSDATE1='19850101'; if strcmp(TAVG,'daily') DSDATE1='19850104';  end 
DSDATE2=datestr(datenum(2008,01,194)+1,'yyyymmdd');
DSDate1=datenum(DSDATE1,'yyyymmdd');
DSDate2=datenum(DSDATE2,'yyyymmdd');
DSDateRT=datenum('20070101','yyyymmdd'); % real time data after DSDateRT
year1=str2num(DSDATE1(1:4));
year2=str2num(DSDATE2(1:4));


if ~isfield(R,'Passes') R.Passes=DSPass; end
if ~isfield(R,'DATE1') R.DATE1=DSDATE1; end
if ~isfield(R,'DATE2') R.DATE2=DSDATE2; end
if ~isfield(R,'DATEINCR') R.DATEINCR=1; end

Passes=R.Passes;DATE1=R.DATE1;DATE2=R.DATE2;DATEINCR=R.DATEINCR;
Date1=datenum(DATE1,'yyyymmdd');Date2=datenum(DATE2,'yyyymmdd');

SatPasses={};SatPassesLST={};
for kP=1:length(DSPass)
    if ~isempty(strmatch(DSPass{kP},Passes)) 
        SatPasses{end+1}=DSPass{kP};
        SatPassesLST{end+1}=DSPassLST{kP};
    end
end
% passes are indicated by 1,3
%except between these dates             
J1PASS10=datenum(2003,01,01); 
J2PASS10=datenum(2005,01,155);
if strcmp(TAVG,'daily')    J2PASS10=datenum(2005,01,155);end
if strcmp(TAVG,'5day')     J2PASS10=datenum(2005,01,155);end
if strcmp(TAVG,'7day')     J2PASS10=datenum(2005,01,154);end
if strcmp(TAVG,'8day')     J2PASS10=datenum(2005,01,160);end
if strcmp(TAVG,'monthly')  J2PASS10=datenum(2005,07,0);end
if strcmp(TAVG,'yearly')   J2PASS10=datenum(2005,01,00);end

% 4 2
% tricky for weekly averages
% yearly average for 2005 is not defined. file is not available.

RESO='04'; % 4km
for j=1:length(Fields)
FIELD=Fields{j};TYPE=FIELD;
BitCodes{j}='m'; % for nobs,qual,msk1,msk2
if ~isempty(strmatch(TYPE,{'sst','bsst','sdev'})) BitCodes{j}='s'; end
end


% initialize arrays
Time=[];
for j=1:length(Fields)
FIELD=Fields{j};
eval(['URLPATH.' FIELD '={};'])
eval(['URLFILE.' FIELD '={};'])
end

for year=year1:year2
YYYY=num2str(year);
    NDays=datenum(year,12,31)-datenum(year,01,01)+1; 
    if strcmp(TAVG,'daily')     NT=NDays;         AVGPERIOD='d';  end
    if strcmp(TAVG,'5day')      NT=floor(NDays/5); AVGPERIOD='5';  end
    if strcmp(TAVG,'7day')      NT=floor(NDays/7); AVGPERIOD='w';  end
    if strcmp(TAVG,'8day')      NT=floor(NDays/8); AVGPERIOD='8';  end
    if strcmp(TAVG,'monthly')   NT=12;            AVGPERIOD='m';  end
    if strcmp(TAVG,'yearly')    NT=1;             AVGPERIOD='y';  end
        
    for kt=1:DATEINCR:NT % browse time moments within each year
        
        if strcmp(TAVG,'daily')
j1=kt;            
OBSDATE=[YYYY num2str(j1,'%03d')];
dj=1;
%NOMDATE=datestr(datenum(year,01,j1),'yyyymmdd'); % middle of interval
%NOMDATE=datestr(datenum(year,01,j1),'yyyymmdd'); % start date
NomDate=datenum(year,01,j1); % start date
        elseif strcmp(TAVG,'5day')
dj=5;j1=(kt-1)*dj+1;j2=j1+dj-1;            
OBSDATE=[YYYY num2str(j1,'%03d') '-' YYYY num2str(j2,'%03d')]; 
%NOMDATE=datestr(datenum(year,01,j1+2),'yyyymmdd');
%NOMDATE=datestr(datenum(year,01,j1),'yyyymmdd'); % start date
NomDate=datenum(year,01,j1); % start date
        elseif strcmp(TAVG,'7day')
dj=7;j1=(kt-1)*dj+1;j2=j1+dj-1;            
OBSDATE=[YYYY num2str(kt,'%02d')]; 
%NOMDATE=datestr(datenum(year,01,j1+3),'yyyymmdd');
%NOMDATE=datestr(datenum(year,01,j1),'yyyymmdd'); % start date
NomDate=datenum(year,01,j1); % start date
        elseif strcmp(TAVG,'8day')
dj=8;j1=(kt-1)*dj+1;j2=j1+dj-1;            
OBSDATE=[YYYY num2str(j1,'%03d') '-' YYYY num2str(j2,'%03d')]; 
%NOMDATE=datestr(datenum(year,01,j1+4),'yyyymmdd');
%NOMDATE=datestr(datenum(year,01,j1),'yyyymmdd'); % start date
NomDate=datenum(year,01,j1); % start date
        elseif strcmp(TAVG,'monthly')
dj=30;j1=(kt-1)*dj+1;j2=j1+dj-1;            
OBSDATE=[YYYY num2str(kt,'%02d')];
%NOMDATE=datestr(datenum(year,kt,15),'yyyymmdd');
%NOMDATE=datestr(datenum(year,kt,01),'yyyymmdd'); % start date
NomDate=datenum(year,kt,01); % start date
        elseif strcmp(TAVG,'yearly')
dj=365;
OBSDATE=[YYYY]; 
%NOMDATE=datestr(datenum(year,07,01),'yyyymmdd');
%NOMDATE=datestr(datenum(year,01,01),'yyyymmdd'); % start date
NomDate=datenum(year,01,01); % start date
        end
        
        for kP=1:length(SatPasses)
            PASS=SatPasses{kP};
            PassLST=SatPassesLST{kP};

            
% passes indicated 1,2,3,4            
DAYNIGHT='1'; PassLST=2/24; if strcmp(PASS,'day') DAYNIGHT='3'; PassLST=14/24; end  
if (NomDate>=J1PASS10) & (NomDate<=J2PASS10)
% passes 4 2  (22 and 10)    
DAYNIGHT='4'; PassLST=22/24; if strcmp(PASS,'day') DAYNIGHT='2'; PassLST=10/24; end 
end

Time1=NomDate+PassLST;
        
VERSION='pfv50'; 
if NomDate>=DSDateRT 
    VERSION='pfrt'; 
end    

                if ... 
NomDate >= DSDate1 & NomDate < DSDate2 & NomDate >= Date1 & NomDate <= Date2
Time(end+1)=Time1;

                for j=1:length(Fields)
FIELD=Fields{j};
TYPE=FIELD;
BITCODE=BitCodes{j};
BITS=''; if BITCODE=='s' & year  < 2002 BITS='-16b'; end

PATH1=['/' TAVG '/' PASS '/04km/' YYYY '/' FIELD '/'];
FN1=[ OBSDATE '.' BITCODE RESO AVGPERIOD DAYNIGHT VERSION '-' TYPE BITS '.hdf'];

eval(['URLPATH.' FIELD '{end+1}=PATH1;'])
eval(['URLFILE.' FIELD '{end+1}=FN1;'])
                end
            end
        end %kP
    end
end

% cut and transpose cell arrays
Time=Time';
%TIME=datestr(Time,'yyyymmddHHMMSS');
for j=1:length(Fields)
FIELD=Fields{j};
eval(['URLPATH.' FIELD '=URLPATH.' FIELD ''';'])
eval(['URLFILE.' FIELD '=URLFILE.' FIELD ''';'])
end

end % if strcmp(R.DataSetBranch,'Pathfinder4km_Climatology')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

